@@ -38,12 +38,12 @@ use tuirealm::{Frame, MockComponent, State, StateValue};
 
 // -- States
 
-struct OwnStates {
-    list_index: usize, // Index of selected item in list
-    list_len: usize,   // Lines in text area
+pub struct ListStates {
+    pub list_index: usize, // Index of selected item in list
+    pub list_len: usize,   // Lines in text area
 }
 
-impl Default for OwnStates {
+impl Default for ListStates {
     fn default() -> Self {
         Self {
             list_index: 0,
@@ -52,7 +52,7 @@ impl Default for OwnStates {
     }
 }
 
-impl OwnStates {
+impl ListStates {
     /// ### set_list_len
     ///
     /// Set list length
@@ -147,7 +147,7 @@ impl OwnStates {
 /// represents a read-only text component without any container.
 pub struct List {
     props: Props,
-    states: OwnStates,
+    pub states: ListStates,
     hg_str: Option<String>, // CRAP CRAP CRAP. Thanks to the author of tui-realm for using references every f time
 }
 
@@ -155,7 +155,7 @@ impl Default for List {
     fn default() -> Self {
         Self {
             props: Props::default(),
-            states: OwnStates::default(),
+            states: ListStates::default(),
             hg_str: None,
         }
     }
@@ -305,26 +305,26 @@ impl MockComponent for List {
                         .collect(), // Make List item from TextSpan
                     _ => Vec::new(),
                 };
-            let highlighted_color: Color = match self
+            let highlighted_color = self
                 .props
                 .get(Attribute::HighlightedColor)
-                .map(|x| x.unwrap_color())
-            {
-                None => match focus {
-                    true => background,
-                    false => foreground,
-                },
-                Some(color) => color,
-            };
-            let (fg, bg): (Color, Color) = match active {
-                true => (background, highlighted_color),
-                false => (highlighted_color, background),
+                .map(|x| x.unwrap_color());
+            let modifiers = match focus {
+                true => modifiers | TextModifiers::REVERSED,
+                false => modifiers,
             };
             // Make list
             let mut list = TuiList::new(list_items)
                 .block(div)
-                .start_corner(Corner::TopLeft)
-                .highlight_style(Style::default().fg(fg).bg(bg).add_modifier(modifiers));
+                .style(Style::default().fg(foreground).bg(background))
+                .start_corner(Corner::TopLeft);
+            if let Some(highlighted_color) = highlighted_color {
+                list = list.highlight_style(
+                    Style::default()
+                        .fg(highlighted_color)
+                        .add_modifier(modifiers),
+                );
+            }
             // Highlighted symbol
             self.hg_str = self
                 .props
@@ -446,7 +446,7 @@ mod tests {
 
     #[test]
     fn list_states() {
-        let mut states = OwnStates::default();
+        let mut states = ListStates::default();
         assert_eq!(states.list_index, 0);
         assert_eq!(states.list_len, 0);
         states.set_list_len(5);
