@@ -28,30 +28,31 @@
 use tuirealm::command::{Cmd, CmdResult, Direction};
 use tuirealm::props::{
     Alignment, AttrValue, Attribute, Borders, Color, PropPayload, PropValue, Props, Style,
+    TextModifiers,
 };
 use tuirealm::tui::{layout::Rect, text::Spans, widgets::Tabs};
 use tuirealm::{Frame, MockComponent, State, StateValue};
 
 // -- states
 
-/// ## OwnStates
+/// ## RadioStates
 ///
-/// OwnStates contains states for this component
-struct OwnStates {
-    choice: usize,        // Selected option
-    choices: Vec<String>, // Available choices
+/// RadioStates contains states for this component
+pub struct RadioStates {
+    pub choice: usize,        // Selected option
+    pub choices: Vec<String>, // Available choices
 }
 
-impl Default for OwnStates {
+impl Default for RadioStates {
     fn default() -> Self {
-        OwnStates {
+        RadioStates {
             choice: 0,
             choices: Vec::new(),
         }
     }
 }
 
-impl OwnStates {
+impl RadioStates {
     /// ### next_choice
     ///
     /// Move choice index to next choice
@@ -76,7 +77,7 @@ impl OwnStates {
 
     /// ### set_choices
     ///
-    /// Set OwnStates choices from a vector of text spans
+    /// Set RadioStates choices from a vector of text spans
     /// In addition resets current selection and keep index if possible or set it to the first value
     /// available
     pub fn set_choices(&mut self, spans: &[String]) {
@@ -104,14 +105,14 @@ impl OwnStates {
 /// Radio component represents a group of tabs to select from
 pub struct Radio {
     props: Props,
-    states: OwnStates,
+    pub states: RadioStates,
 }
 
 impl Default for Radio {
     fn default() -> Self {
         Self {
             props: Props::default(),
-            states: OwnStates::default(),
+            states: RadioStates::default(),
         }
     }
 }
@@ -212,15 +213,19 @@ impl MockComponent for Radio {
                 .map(|x| x.unwrap_style());
             let div = crate::utils::get_block(borders, title, focus, inactive_style);
             // Make colors
-            let (bg, fg, block_color): (Color, Color, Color) = match focus {
-                true => (foreground, background, foreground),
-                false => (Color::Reset, foreground, Color::Reset),
+            let (fg, block_color): (Color, Color) = match focus {
+                true => (foreground, foreground),
+                false => (foreground, Color::Reset),
+            };
+            let modifiers = match focus {
+                true => TextModifiers::REVERSED,
+                false => TextModifiers::empty(),
             };
             let radio: Tabs = Tabs::new(choices)
                 .block(div)
                 .select(self.states.choice)
-                .style(Style::default().fg(block_color))
-                .highlight_style(Style::default().fg(fg).bg(bg));
+                .style(Style::default().fg(block_color).bg(background))
+                .highlight_style(Style::default().fg(fg).add_modifier(modifiers));
             render.render_widget(radio, area);
         }
     }
@@ -288,7 +293,7 @@ mod test {
 
     #[test]
     fn test_components_radio_states() {
-        let mut states: OwnStates = OwnStates::default();
+        let mut states: RadioStates = RadioStates::default();
         assert_eq!(states.choice, 0);
         assert_eq!(states.choices.len(), 0);
         let choices: &[String] = &[
