@@ -41,12 +41,12 @@ use tuirealm::{Frame, MockComponent, State, StateValue};
 
 // -- States
 
-struct OwnStates {
-    list_index: usize, // Index of selected item in textarea
-    list_len: usize,   // Lines in text area
+pub struct TableStates {
+    pub list_index: usize, // Index of selected item in textarea
+    pub list_len: usize,   // Lines in text area
 }
 
-impl Default for OwnStates {
+impl Default for TableStates {
     fn default() -> Self {
         Self {
             list_index: 0,
@@ -55,7 +55,7 @@ impl Default for OwnStates {
     }
 }
 
-impl OwnStates {
+impl TableStates {
     /// ### set_list_len
     ///
     /// Set list length
@@ -150,7 +150,7 @@ impl OwnStates {
 /// represents a read-only text component without any container.
 pub struct Table {
     props: Props,
-    states: OwnStates,
+    pub states: TableStates,
     hg_str: Option<String>, // CRAP CRAP CRAP
     headers: Vec<String>,   // CRAP CRAP CRAP
 }
@@ -159,7 +159,7 @@ impl Default for Table {
     fn default() -> Self {
         Self {
             props: Props::default(),
-            states: OwnStates::default(),
+            states: TableStates::default(),
             hg_str: None,
             headers: Vec::default(),
         }
@@ -347,10 +347,6 @@ impl MockComponent for Table {
                 .props
                 .get(Attribute::FocusStyle)
                 .map(|x| x.unwrap_style());
-            let active: bool = match self.is_scrollable() {
-                true => focus,
-                false => true,
-            };
             let row_height = self
                 .props
                 .get_or(Attribute::Height, AttrValue::Size(1))
@@ -377,22 +373,10 @@ impl MockComponent for Table {
                     .collect(), // Make List item from TextSpan
                 _ => Vec::new(),
             };
-            let highlighted_color: Color = match self
+            let highlighted_color = self
                 .props
                 .get(Attribute::HighlightedColor)
-                .map(|x| x.unwrap_color())
-            {
-                None => match focus {
-                    true => background,
-                    false => foreground,
-                },
-                Some(color) => color,
-            };
-            let (fg, bg): (Color, Color) = match active {
-                true => (background, highlighted_color),
-                false => (highlighted_color, background),
-            };
-            // Make list
+                .map(|x| x.unwrap_color());
             let widths: Vec<Constraint> = self.layout();
             let mut table = TuiTable::new(rows)
                 .block(crate::utils::get_block(
@@ -401,8 +385,15 @@ impl MockComponent for Table {
                     focus,
                     inactive_style,
                 ))
-                .highlight_style(Style::default().fg(fg).bg(bg).add_modifier(modifiers))
                 .widths(&widths);
+            if let Some(highlighted_color) = highlighted_color {
+                table = table.highlight_style(Style::default().fg(highlighted_color).add_modifier(
+                    match focus {
+                        true => modifiers | TextModifiers::REVERSED,
+                        false => modifiers,
+                    },
+                ));
+            }
             // Highlighted symbol
             self.hg_str = self
                 .props
@@ -557,7 +548,7 @@ mod tests {
 
     #[test]
     fn table_states() {
-        let mut states = OwnStates::default();
+        let mut states = TableStates::default();
         assert_eq!(states.list_index, 0);
         assert_eq!(states.list_len, 0);
         states.set_list_len(5);
